# Examples

These documents include examples of how to use octofitterpy:

* Relative astrometry orbit fit: [basic-fit-example.md](./basic-fit-example.md)
* RV orbit fit: [basic-fit-example.md](./rv-examples.md)
* Tutoral notebook: [demo.ipynb](./demo.ipynb)